pub struct DocId(pub u32);Expand description
Index into the lazy documentation store. The Phase-2 thin slice never populates the
store, so every doc field is None; the fields exist now so wiring docs in is additive
(Playbook 4.6).
Tuple Fields
0: u32Trait Implementations
Sourceimpl Archive for DocId
impl Archive for DocId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDocId
type Archived = ArchivedDocId
The archived representation of this type. Read more
Sourcetype Resolver = DocIdResolver
type Resolver = DocIdResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Copy for DocId
impl Eq for DocId
impl StructuralPartialEq for DocId